@@ -3,9 +3,10 @@ SatNOGS Processor subpackage initialization
 """
 from __future__ import absolute_import, division, print_function
 
+from .b64encode import B64encode
 from .b85decode import B85decode
 from .b85encode import B85encode
 from .elfin_pp import ElfinPp
 from .scrambler import Scrambler
 
-__all__ = ['ElfinPp', 'B85encode', 'B85decode', 'Scrambler']
+__all__ = ['ElfinPp', 'B85encode', 'B85decode', 'Scrambler', 'B64encode']
